@@ -9,20 +9,17 @@ from typing import AsyncGenerator, List, Optional, Union
 
 # Third-party imports
 import httpx
-from dotenv import load_dotenv
 from langfuse import observe
 from langfuse.openai import AsyncOpenAI
 from pydantic import BaseModel
 from tenacity import retry, stop_after_attempt, wait_exponential
 
 # Local imports
-from ..components import MessageStorageBase, MessageStorageLocal
-from ..schemas import Message, ToolCall
+from ..components import MessageStorageBase, MessageStorageLocal, MemoryStorageBase, MemoryStorageLocal
+from ..schemas import Message, ToolCall,RoleType, MessageType
 from ..utils.mcp_convertor import MCPTool
 from ..utils.tool_decorator import function_tool
 
-load_dotenv(override=True)
-
 # Configure logging
 logging.basicConfig(
     level=logging.INFO,
@@ -54,7 +51,8 @@ class AgentConfig:
         "**Context Information:**\n"
         "- Current user_id: {user_id}\n"
         "- Current date: {date}\n" 
-        "- Current timezone: {timezone}\n\n\n"
+        "- Current timezone: {timezone}\n\n"
+        "- Retrieve relevant memories for user: {retrieved_memories}\n\n\n"
     )
 
 
@@ -91,7 +89,9 @@ class Agent:
         mcp_servers: Optional[Union[str, List[str]]] = None,
         sub_agents: Optional[List[Union[tuple[str, str, str], 'Agent']]] = None,
         output_type: Optional[type[BaseModel]] = None,
-        message_storage: Optional[MessageStorageBase] = None
+        message_storage: Optional[MessageStorageBase] = None,
+        memory_storage: Optional[MemoryStorageBase] = None,
+        enable_memory: bool = False,
     ):
         """
         Initialize the Agent with optional parameters.
@@ -107,6 +107,8 @@ class Agent:
             sub_agents: List of sub-agents to convert to tools
             output_type: Pydantic model for structured output
             message_storage: MessageStorageBase instance for message storage
+            memory_storage: MemoryStorageBase instance for long-term memory
+            enable_memory: Whether to enable memory storage and retrieval
         """
         # Basic configuration
         self.name = name or AgentConfig.DEFAULT_NAME
@@ -121,6 +123,12 @@ class Agent:
         else:
             self.message_storage = MessageStorageLocal()
         
+        # Memory setup
+        if memory_storage is not None:
+            self.memory_storage = memory_storage
+        else:
+            self.memory_storage = MemoryStorageLocal(collection_name = self.name)
+        
         # System prompt setup
         self.system_prompt = AgentConfig.DEFAULT_SYSTEM_PROMPT + (system_prompt or "")
         
@@ -148,62 +156,18 @@ class Agent:
             self.logger.info("Registered agent tools: %s", 
                            [tool.tool_spec['name'] for tool in agent_tools])
 
-    def _normalize_mcp_servers(self, mcp_servers: Optional[Union[str, List[str]]]) -> List[str]:
-        """Normalize MCP servers input to a list."""
-        if not mcp_servers:
-            return []
-        if isinstance(mcp_servers, str):
-            return [mcp_servers]
-        return list(mcp_servers)
-
-    @property
-    def cached_tool_specs(self):
-        """
-        Returns the cached tool specifications, rebuilding if necessary.
-        """
-        if self._should_rebuild_cache():
-            self._rebuild_tool_cache()
-        return self._tool_specs_cache
-
-    def _should_rebuild_cache(self) -> bool:
-        """
-        Determine if the tool specs cache should be rebuilt.
-        Returns:
-        - True if the cache is empty or tools have changed
-        - False if the cache is valid
-        """
-        # If the cache is empty, we need to rebuild
-        if self._tool_specs_cache is None:
-            return True
-
-        # If the MCP tools have been updated, we need to rebuild
-        if self.mcp_tools_last_updated and (
-            self._tools_last_updated is None or 
-            self.mcp_tools_last_updated > self._tools_last_updated
-        ):
-            return True
-        
-        return False
-
-    def _rebuild_tool_cache(self):
-        """
-        Rebuild the tool specs cache.
-        This method collects all tools from both local and MCP sources,
-        and updates the cache with their specifications.
-        """
-        all_tools = list(self.tools.values()) + list(self.mcp_tools.values())
-        self._tool_specs_cache = [fn.tool_spec for fn in all_tools] if all_tools else None
-        self._tools_last_updated = time.time()
+        # Memory enable flag
+        self.enable_memory = enable_memory
 
     async def __call__(
         self,
-        user_message: Union[Message, str],
+        user_message: str,
         user_id: str = AgentConfig.DEFAULT_USER_ID,
         session_id: str = AgentConfig.DEFAULT_SESSION_ID,
         history_count: int = AgentConfig.DEFAULT_HISTORY_COUNT,
         max_iter: int = AgentConfig.DEFAULT_MAX_ITER,
         max_concurrent_tools: int = AgentConfig.DEFAULT_MAX_CONCURRENT_TOOLS,
-        image_source: Optional[str] = None,
+        image_source: Optional[Union[str, List[str]]] = None,
         output_type: Optional[type[BaseModel]] = None,
         stream: bool = False,
     ) -> Union[str, BaseModel, AsyncGenerator[str, None]]:
@@ -223,13 +187,13 @@ class Agent:
     @observe()
     async def chat(
         self,
-        user_message: Union[Message, str],
+        user_message: str,
         user_id: str = AgentConfig.DEFAULT_USER_ID,
         session_id: str = AgentConfig.DEFAULT_SESSION_ID,
         history_count: int = AgentConfig.DEFAULT_HISTORY_COUNT,
         max_iter: int = AgentConfig.DEFAULT_MAX_ITER,
         max_concurrent_tools: int = AgentConfig.DEFAULT_MAX_CONCURRENT_TOOLS,
-        image_source: Optional[str] = None,
+        image_source: Optional[Union[str, List[str]]] = None,
         output_type: Optional[type[BaseModel]] = None,
         stream: bool = False
     ) -> Union[str, BaseModel, AsyncGenerator[str, None]]:
@@ -243,7 +207,7 @@ class Agent:
             history_count: Number of previous messages to include
             max_iter: Maximum model call attempts
             max_concurrent_tools: Maximum number of concurrent tool calls
-            image_source: Source of the image, if any (URL, file path, or base64 string)
+            image_source: Source of the image, if any (URL, file path, or base64 string, or list of these)
             output_type: Pydantic model for structured output
             stream: Whether to stream the response
 
@@ -271,8 +235,19 @@ class Agent:
             # Build input messages once outside the loop
             input_messages = [msg.to_dict() for msg in await self.message_storage.get_messages(user_id, session_id, history_count)]
 
+            messages_without_tool = [input for input in input_messages if input.get("role") != RoleType.TOOL.value]
+            
+            retrieved_memories = []
+            if self.enable_memory:
+                pre_chat = messages_without_tool[-3:] # Use last 4 messages for memory retrieval memory and memory storage
+                retrieved_memories = await self.memory_storage.retrieve(user_id=user_id, query=user_message, limit=5, 
+                                                                        query_context=f"pre_chat:{pre_chat}",enable_query_process=True)
+                
+                asyncio.create_task(self.memory_storage.add(user_id=user_id, messages=messages_without_tool[-2:])) # Store last 2 messages asynchronously
+
             for attempt in range(max_iter):
-                reply_type, response = await self._call_model(input_messages, user_id, session_id, output_type, stream)
+
+                reply_type, response = await self._call_model(input_messages, user_id, session_id, output_type, stream, retrieved_memories)
 
                 if reply_type == ReplyType.SIMPLE_REPLY:
                     if not stream:
@@ -315,10 +290,10 @@ class Agent:
             param_descriptions={
                 "input": "A clear, focused instruction or question for the agent, sufficient to complete the task independently, with any necessary resources included.",
                 "expected_output": "Specification of the desired output format, structure, or content type.",
-                "image_source": "Optional image for analysis. Can be a URL (http/https) or base64 encoded image string."
+                "image_source": "Optional list of image URLs, file paths, or base64 strings to be included in the message. If provided, these images will be used as context for the agent's response."
             }
         )
-        async def tool_func(input: str, expected_output: str,image_source: Optional[str] = None):
+        async def tool_func(input: str, expected_output: str,image_source: Optional[List[str]] = None):
             user_message = f"### User Input:\n{input}"
             if expected_output:
                 user_message += f"\n\n### Expected Output:\n{expected_output}"
@@ -401,13 +376,12 @@ class Agent:
         
         self.mcp_tools_last_updated = now
 
-    async def _store_user_message(self, user_message: Message | str, user_id: str, session_id: str, image_source: Optional[str]) -> None:
-        if isinstance(user_message, str):
-            user_message = Message.create(content=user_message, role="user", image_source=image_source)
+    async def _store_user_message(self, user_message: str, user_id: str, session_id: str, image_source: Optional[Union[str, List[str]]]) -> None:
+        user_message = Message.create(content=user_message, role=RoleType.USER, image_source=image_source)
         await self.message_storage.add_messages(user_id, session_id, user_message)
 
     async def _store_model_reply(self, reply_text: str, user_id: str, session_id: str) -> None:
-        model_msg = Message.create(content=reply_text, role="assistant")
+        model_msg = Message.create(content=reply_text, role=RoleType.ASSISTANT)
         await self.message_storage.add_messages(user_id, session_id, model_msg)
 
     @observe()
@@ -415,8 +389,11 @@ class Agent:
         stop=stop_after_attempt(AgentConfig.RETRY_ATTEMPTS),
         wait=wait_exponential(multiplier=1, min=AgentConfig.RETRY_MIN_WAIT, max=AgentConfig.RETRY_MAX_WAIT)
     )
-    async def _call_model(self, input_msgs: list, user_id: str, session_id: str,
-                          output_type: type[BaseModel] = None, stream: bool = False) -> tuple[ReplyType, object]:
+    async def _call_model(self, input_msgs: list, 
+                          user_id: str, session_id: str,
+                          output_type: type[BaseModel] = None, stream: bool = False,
+                          retrieved_memories: Optional[List[dict]] = None
+                          ) -> tuple[ReplyType, object]:
         """
         Call the AI model with the provided input messages.
         Args:
@@ -433,7 +410,8 @@ class Agent:
             "content": self.system_prompt.format(
                 user_id=user_id, 
                 date=time.strftime('%Y-%m-%d'), 
-                timezone=time.tzname[0]
+                timezone=time.tzname[0],
+                retrieved_memories=retrieved_memories or "No relevant memories found."
             )
         }
 
@@ -490,6 +468,7 @@ class Agent:
                                 if content:
                                     yield content
                         await self._store_model_reply(event.response.output[0].content[0].text, user_id, session_id)
+
                     return ReplyType.SIMPLE_REPLY, stream_generator()
                 elif event_type == "function_call":
                     async for event in response:
@@ -577,8 +556,8 @@ class Agent:
                 result = f"Tool error: {e}"
 
             tool_call_msg = Message(
-                type="function_call",
-                role="tool", 
+                type=MessageType.FUNCTION_CALL,
+                role=RoleType.TOOL,
                 content=f"Calling tool: `{name}` with args: {args}",
                 tool_call=ToolCall(
                     call_id=getattr(tool_call, "call_id", ""),
@@ -595,8 +574,8 @@ class Agent:
                 return result_str[:AgentConfig.TOOL_RESULT_PREVIEW_LENGTH] + '...'
 
             tool_res_msg = Message(
-                type="function_call_output",
-                role="tool",
+                type=MessageType.FUNCTION_CALL_OUTPUT,
+                role=RoleType.TOOL,
                 content=f"Tool `{name}` result: {_format_tool_result_preview(result)}",
                 tool_call=ToolCall(
                     call_id=getattr(tool_call, "call_id", "001"),
@@ -619,11 +598,59 @@ class Agent:
         Returns:
             list: Sanitized list of input messages with no leading function call outputs.
         """
-        while input_messages and input_messages[0].get("type") == "function_call_output":
+        while input_messages and input_messages[0].get("type") == MessageType.FUNCTION_CALL_OUTPUT:
             input_messages.pop(0)
         return input_messages
     
 
+    def _normalize_mcp_servers(self, mcp_servers: Optional[Union[str, List[str]]]) -> List[str]:
+        """Normalize MCP servers input to a list."""
+        if not mcp_servers:
+            return []
+        if isinstance(mcp_servers, str):
+            return [mcp_servers]
+        return list(mcp_servers)
+
+    @property
+    def cached_tool_specs(self):
+        """
+        Returns the cached tool specifications, rebuilding if necessary.
+        """
+        if self._should_rebuild_cache():
+            self._rebuild_tool_cache()
+        return self._tool_specs_cache
+
+    def _should_rebuild_cache(self) -> bool:
+        """
+        Determine if the tool specs cache should be rebuilt.
+        Returns:
+        - True if the cache is empty or tools have changed
+        - False if the cache is valid
+        """
+        # If the cache is empty, we need to rebuild
+        if self._tool_specs_cache is None:
+            return True
+
+        # If the MCP tools have been updated, we need to rebuild
+        if self.mcp_tools_last_updated and (
+            self._tools_last_updated is None or 
+            self.mcp_tools_last_updated > self._tools_last_updated
+        ):
+            return True
+        
+        return False
+
+    def _rebuild_tool_cache(self):
+        """
+        Rebuild the tool specs cache.
+        This method collects all tools from both local and MCP sources,
+        and updates the cache with their specifications.
+        """
+        all_tools = list(self.tools.values()) + list(self.mcp_tools.values())
+        self._tool_specs_cache = [fn.tool_spec for fn in all_tools] if all_tools else None
+        self._tools_last_updated = time.time()
+
+
     def _convert_http_agent_to_tool(
         self, 
         server: str, 
@@ -646,10 +673,10 @@ class Agent:
             param_descriptions={
                 "input": "A clear, focused instruction or question for the agent, sufficient to complete the task independently, with any necessary resources included.",
                 "expected_output": "Specification of the desired output format, structure, or content type.",
-                "image_source": "Optional image for analysis. Can be a URL (http/https) or base64 encoded image string."
+                "image_source": "Optional list of image URLs, file paths, or base64 strings to be included in the message. If provided, these images will be used as context for the agent's response."
             }
         )
-        async def tool_func(input: str, expected_output: str, image_source: Optional[str] = None):
+        async def tool_func(input: str, expected_output: str, image_source: Optional[List[str]] = None):
             # 构建消息和请求体
             user_message = f"### User Input:\n{input}"
             if expected_output:
@@ -705,4 +732,4 @@ class Agent:
                 self.logger.exception(f"HTTP Agent call failed: {e}")
                 return f"Unexpected error: {str(e)}"
 
-        return tool_func
\ No newline at end of file
+        return tool_func
