@@ -1,5 +1,4 @@
 import os
-import yaml
 import argparse
 import asyncio
 import uuid
@@ -7,17 +6,15 @@ import logging
 from typing import Optional
 from dotenv import load_dotenv
 
-load_dotenv(override=True)
-
 from .base import BaseAgentRunner
 
 
-class CLIAgent(BaseAgentRunner):
+class AgentCLI(BaseAgentRunner):
     """CLI Agent for xAgent."""
     
     def __init__(self, config_path: Optional[str] = None, toolkit_path: Optional[str] = None, verbose: bool = False):
         """
-        Initialize CLIAgent.
+        Initialize AgentCLI.
         
         Args:
             config_path: Path to configuration file (if None, uses default configuration)
@@ -26,14 +23,22 @@ class CLIAgent(BaseAgentRunner):
         """
         # Configure logging based on verbose setting
         self.verbose = verbose
+        
+        # Always suppress Langfuse logs regardless of verbose mode
+        logging.getLogger("langfuse").setLevel(logging.CRITICAL)
+        
         if not verbose:
             # Suppress most logging except critical errors
             logging.getLogger().setLevel(logging.CRITICAL)
             logging.getLogger("xagent").setLevel(logging.CRITICAL)
+            # Suppress all warnings when not in verbose mode
+            import warnings
+            warnings.filterwarnings("ignore")
         else:
             # Enable verbose logging
             logging.getLogger().setLevel(logging.INFO)
             logging.getLogger("xagent").setLevel(logging.INFO)
+            # Keep Langfuse suppressed even in verbose mode
         
         # Initialize the base agent runner
         super().__init__(config_path, toolkit_path)
@@ -262,8 +267,11 @@ def create_default_config_file(config_path: str = "config/agent.yaml"):
   capabilities:
     tools:
       - web_search
-    mcp_servers: []
+      - calculate_square # Custom tool
+    mcp_servers:
+      - http://localhost:8001/mcp/  # Example MCP server
   message_storage: local
+  enable_memory: false
 
 server:
   host: 0.0.0.0
@@ -332,6 +340,7 @@ def main():
     parser.add_argument("--user_id", help="User ID for the session")
     parser.add_argument("--session_id", help="Session ID for the chat")
     parser.add_argument("--verbose", "-v", action="store_true", help="Enable verbose logging")
+    parser.add_argument("--env", default=".env", help="Path to .env file")
     
     # Special commands as optional arguments
     parser.add_argument("--ask", metavar="MESSAGE", help="Ask a single question instead of starting interactive chat")
@@ -340,6 +349,15 @@ def main():
     # Parse arguments
     args = parser.parse_args()
     
+    # Load .env file (default: .env in current directory)
+    if os.path.exists(args.env):
+        load_dotenv(args.env, override=True)
+        if args.verbose:
+            print(f"\n✅ Loaded .env file from: {args.env}\n")
+    else:
+        if args.verbose:
+            print(f"\n⚠️  .env file not found: {args.env}\n")
+    
     try:
         # Handle init command
         if args.init:
@@ -348,12 +366,12 @@ def main():
         
         # Handle single question
         if args.ask:
-            cli_agent = CLIAgent(
+            agent_cli = AgentCLI(
                 config_path=args.config,
                 toolkit_path=args.toolkit_path,
                 verbose=args.verbose
             )
-            response = asyncio.run(cli_agent.chat_single(
+            response = asyncio.run(agent_cli.chat_single(
                 message=args.ask,
                 user_id=args.user_id,
                 session_id=args.session_id
@@ -362,14 +380,14 @@ def main():
             return
         
         # Default behavior: start interactive chat
-        cli_agent = CLIAgent(
+        agent_cli = AgentCLI(
             config_path=args.config,
             toolkit_path=args.toolkit_path,
             verbose=args.verbose
         )
         
         # Start interactive chat
-        asyncio.run(cli_agent.chat_interactive(
+        asyncio.run(agent_cli.chat_interactive(
             user_id=args.user_id,
             session_id=args.session_id
         ))
